
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#pragma once

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "libcallaudio.h" */

GType call_audio_mode_get_type (void);
#define CALL_TYPE_AUDIO_MODE (call_audio_mode_get_type())

GType call_audio_speaker_state_get_type (void);
#define CALL_TYPE_AUDIO_SPEAKER_STATE (call_audio_speaker_state_get_type())

GType call_audio_mic_state_get_type (void);
#define CALL_TYPE_AUDIO_MIC_STATE (call_audio_mic_state_get_type())

G_END_DECLS

/* Generated data ends here */

